# Views Aggregation
### On this page
  * [Views Aggregation](https://help.sap.com/docs/leanix/ea/views-aggregation#views-aggregation)
  * [Selecting a Related Fact Sheet](https://help.sap.com/docs/leanix/ea/views-aggregation#selecting-a-related-fact-sheet)
  * [Obsolescence Risk View Aggregation](https://help.sap.com/docs/leanix/ea/views-aggregation#obsolescence-risk-view-aggregation)
  * [Obsolescence Risk Details](https://help.sap.com/docs/leanix/ea/views-aggregation#obsolescence-risk-details)


Understand and customize aggregation methods in SAP LeanIX views and learn how the obsolescence risk view is aggregated based on IT component lifecycle statuses.
